
To be done
==========

Mac support

eta > 9 months


Version Release Notes
=====================

1.0.0
-----
* calls to the unregister and register are now thread safe
* kp keys work properly
* kp_unite option

0.1.4
-----
* Bug fix on linux where pressing numlock would crash us..

0.1.3
-----

* Custom args can now be passed to a custom consumer


